;;; DO NOT MODIFY THIS FILE
(if (featurep 'latin-euro-standards-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "latin-euro-standards/_pkg.el")

(package-provide 'latin-euro-standards :version 1.07 :author-version "1.07" :type 'regular)

;;;***

;;;### (autoloads nil "latin-euro-latin10" "latin-euro-standards/latin-euro-latin10.el")

(unless (find-charset 'latin-iso8859-16) (make-charset 'latin-iso8859-16 "ISO8859-16 (Latin 10)" (append (if (emacs-version>= 21 4) '(short-name "Latin-10" long-name "ISO8859-16 (Latin 10)") nil) '(registry "iso8859-16" dimension 1 columns 1 chars 96 final ?f graphic 1 direction l2r))) (require 'cl) (load "cl-macs" nil t) (loop for c from 64 to 127 do (modify-syntax-entry (make-char 'latin-iso8859-16 c) "w")) (mapc (lambda (c) (modify-syntax-entry (make-char 'latin-iso8859-16 c) "w")) '(161 162 163 166 168 170 172 174 175 179 180 181 184 185 186 188 189 190 191)))

(unless (find-coding-system 'iso-8859-16) (make-coding-system 'iso-8859-16 'iso2022 "MIME ISO-8859-16" '(charset-g0 ascii charset-g1 latin-iso8859-16 charset-g2 t charset-g3 t mnemonic "MIME/Ltn-10")))

(unless (assoc "Latin-10" language-info-alist) (defun setup-latin10-environment nil "Set up multilingual environment (MULE) for European Latin-10 users." (interactive) (set-language-environment "Latin-10")) (apply (function set-language-info-alist) (append (backquote ("Latin-10" ((charset ascii latin-iso8859-16) (coding-system iso-8859-16) (coding-priority iso-8859-16) (input-method . "latin-10-prefix") (sample-text \, (format "Hey, if you know Romanian, send sample encoded text (eg, using \"comma-below\"\ncharacters) to xemacs-beta@xemacs.org.  Please use a MIME\napplication/octet-stream attachment if possible.")) (documentation . "This is a generic language environment for Latin-10 (ISO-8859-16).  It\nsupports Romanian and most Western European languages.")))) (if (emacs-version>= 21 1 15) '(("European")) nil))))

;;;***

;;;### (autoloads nil "latin-euro-latin7" "latin-euro-standards/latin-euro-latin7.el")

;;;***

;;;### (autoloads nil "latin-euro-latin8" "latin-euro-standards/latin-euro-latin8.el")

(unless (find-charset 'latin-iso8859-14) (make-charset 'latin-iso8859-14 "ISO8859-14 (Latin 8)" (append (if (emacs-version>= 21 4) '(short-name "Latin-8" long-name "ISO8859-16 (Latin 8)") nil) '(registry "iso8859-14" dimension 1 columns 1 chars 96 final ?_ graphic 1 direction l2r))) (require 'cl) (load "cl-macs" nil t) (loop for c from 32 to 127 do (modify-syntax-entry (make-char 'latin-iso8859-14 c) "w")) (mapc (lambda (c) (modify-syntax-entry (make-char 'latin-iso8859-14 c) "_")) '(163 167 169 173 174 182)))

(unless (find-coding-system 'iso-8859-14) (make-coding-system 'iso-8859-14 'iso2022 "MIME ISO-8859-14" '(charset-g0 ascii charset-g1 latin-iso8859-14 charset-g2 t charset-g3 t mnemonic "MIME/Ltn-8")))

(unless (assoc "Latin-8" language-info-alist) (defun setup-latin8-environment nil "Set up multilingual environment (MULE) for European Latin-8 users." (interactive) (set-language-environment "Latin-8")) (apply (function set-language-info-alist) (append (backquote ("Latin-8" ((charset ascii latin-iso8859-14) (coding-system iso-8859-14) (coding-priority iso-8859-14) (input-method . "latin-8-prefix") (sample-text (\, (apply 'format "Following is the first paragraph of Myles na gCopaleen's An B%cal Bocht, %c\nEibhl%cn N%c Nuall%cin, 1941, 1999.  The first asterisked word is a rendering\nof \"diversions\" in Irish orthography, and the second \"adventures\":\n\n\"T%c na nithe at%c luaithe agam sa scr%cbhinn seo %c gcur agam ann de %cr%c go\n%cfuil an saol eile ag druidim liom go sciobtha -- i %cfad uainn go l%cir an\ndrochrud agus n%cr aithn%c an t-ainspiorad mar %cr%cthair m%c -- agus f%cs 'mar\nn%c beidh %cr leith%cid%c ar%cs ann.' Is c%cir cu%c go gcuirf%c ar f%cil don %cuintir\na leanann sinn faisn%cis %cigin ar na dibheairseans* agus na haidbhintiurs** a\nbh%c ann len%cr linn mar nach mbeidh %cr sampla%c ar%cs ann go br%cch agus mar\nnach mbeidh aon saol úd againne nach %cfuil anois ann. \"\n\n* scl%cip\n** eachtra%c" (mapcar '(lambda (code) (make-char 'latin-iso8859-14 code)) '(105 41 109 109 97 97 97 109 97 34 109 34 34 105 97 109 34 97 105 115 97 97 105 109 109 115 109 109 97 53 105 105 109 97 97 109 109 97 34 105 109))))) (documentation . "This is a generic language environment for Latin-8 (ISO-8859-14).  It\nsupports Celtic and most Western European languages.")))) (if (emacs-version>= 21 1 15) '(("European")) nil))))

;;;***

;;;### (autoloads nil "latin-euro-latin9" "latin-euro-standards/latin-euro-latin9.el")

(unless (find-charset 'latin-iso8859-15) (make-charset 'latin-iso8859-15 "ISO8859-15 (Latin 9)" (append (if (emacs-version>= 21 4) '(short-name "Latin-9" long-name "ISO8859-15 (Latin 9)") nil) '(registry "iso8859-15" dimension 1 columns 1 chars 96 final ?b graphic 1 direction l2r))) (require 'cl) (load "cl-macs" nil t) (loop for c from 64 to 127 do (modify-syntax-entry (make-char 'latin-iso8859-15 c) "w")) (mapc (lambda (c) (modify-syntax-entry (make-char 'latin-iso8859-15 c) "w")) '(166 168 180 184 188 189 190)) (modify-syntax-entry (make-char 'latin-iso8859-15 32) "w") (modify-syntax-entry (make-char 'latin-iso8859-15 87) "_") (modify-syntax-entry (make-char 'latin-iso8859-15 119) "_"))

(unless (find-coding-system 'iso-8859-15) (make-coding-system 'iso-8859-15 'iso2022 "MIME ISO-8859-15" '(charset-g0 ascii charset-g1 latin-iso8859-15 charset-g2 t charset-g3 t mnemonic "MIME/Ltn-9")))

(unless (assoc "Latin-9" language-info-alist) (defun setup-latin9-environment nil "Set up multilingual environment (MULE) for European Latin-9 users." (interactive) (set-language-environment "Latin-9")) (apply (function set-language-info-alist) (append (backquote ("Latin-9" ((charset ascii latin-iso8859-15) (coding-system iso-8859-15) (coding-priority iso-8859-15) (input-method . "latin-9-prefix") (sample-text \, (format "Hello, Hej, Tere, Hei, Bonjour, Gr%c%c Gott, Ciao, %cHola!, my %c0.02" (make-char 'latin-iso8859-15 124) (make-char 'latin-iso8859-15 95) (make-char 'latin-iso8859-15 33) (make-char 'latin-iso8859-15 36))) (documentation . "This is a generic language environment for Latin-9 (ISO-8859-15).  It\nsupports the Euro and the following languages:\n Danish, Dutch, English, Faeroese, Finnish, French, German, Icelandic,\n Irish, Italian, Norwegian, Portuguese, Spanish, and Swedish.\nWe also have a German specific language environment \"German\".")))) (if (emacs-version>= 21 1 15) '(("European")) nil))))

(defun-when-void set-character-of-keysym (keysym character) "Make CHARACTER be inserted when KEYSYM is pressed, \nand the key has been bound to `self-insert-command'.  Contrary to the case\nwith `get-character-of-keysym', KEYSYM may only be a symbol, characters are\nforbidden.  " (check-argument-type 'symbolp keysym) (check-argument-type 'characterp character) (put keysym 'ascii-character character))

(defun-when-void get-character-of-keysym (keysym) "Return the character inserted when KEYSYM is pressed, \nand the key is bound to `self-insert-command'.  " (check-argument-type 'symbolp keysym) (event-to-character (make-event 'key-press (list 'key keysym))))

(flet ((define-keysym-as-char (keysym character) (unless (lookup-key global-map (vector keysym)) (define-key global-map (vector keysym) (function self-insert-command))) (unless (get-character-of-keysym keysym) (set-character-of-keysym keysym character))) (foo (k o) (define-keysym-as-char k (make-char 'latin-iso8859-15 o)))) (foo 'EuroSign 36) (foo 'Scaron 38) (foo 'scaron 40) (foo 'Zcaron 52) (foo 'zcaron 56) (foo 'OE 60) (foo 'oe 61) (foo 'Ydiaeresis 62))

;;;***

(provide 'latin-euro-standards-autoloads)
